@@ -16,6 +16,7 @@
 #include "Gui/SelectionEditor.h"
 #include "Gui/SpectacleWindow.h"
 #include "Gui/InlineMessageModel.h"
+#include "ImageMetaData.h"
 #include "OcrManager.h"
 #include "Platforms/ImagePlatformXcb.h"
 #include "Platforms/PlatformLoader.h"
@@ -204,10 +205,12 @@ SpectacleCore::SpectacleCore(QObject *parent)
         m_annotationDocument->setBaseImage(image);
         setExportImage(image);
         ExportManager::instance()->updateTimestamp();
-        SelectionEditor::instance()->reset();
         initCaptureWindows(CaptureWindow::Image);
         SpectacleWindow::setTitleForAll(SpectacleWindow::Unsaved);
         SpectacleWindow::setVisibilityForAll(QWindow::FullScreen);
+        // SelectionEditor::reset has to be delayed until after all the DPRs are correct on Wayland.
+        connect(m_captureWindows.front().get(), &CaptureWindow::allExposed, //
+                SelectionEditor::instance(), &SelectionEditor::reset, Qt::SingleShotConnection);
     });
 
     // The behavior happens to be very similar right now, so we use a shared base function
@@ -432,10 +435,12 @@ SpectacleCore::SpectacleCore(QObject *parent)
         onScreenshotOrRecordingFailed(message, uiMessage, &SpectacleCore::dbusRecordingFailed);
     });
     connect(videoPlatform, &VideoPlatform::regionRequested, this, [this] {
-        SelectionEditor::instance()->reset();
         initCaptureWindows(CaptureWindow::Video);
         SpectacleWindow::setTitleForAll(SpectacleWindow::Unsaved);
         SpectacleWindow::setVisibilityForAll(QWindow::FullScreen);
+        // SelectionEditor::reset has to be delayed until after all the DPRs are correct on Wayland.
+        connect(m_captureWindows.front().get(), &CaptureWindow::allExposed, //
+                SelectionEditor::instance(), &SelectionEditor::reset, Qt::SingleShotConnection);
     });
 
     // set up the export manager
@@ -658,7 +663,10 @@ SpectacleCore::SpectacleCore(QObject *parent)
 
     connect(m_annotationDocument.get(), &AnnotationDocument::repaintNeeded, m_annotationSyncTimer.get(), qOverload<>(&QTimer::start));
     connect(m_annotationSyncTimer.get(), &QTimer::timeout, this, [this] {
-        ExportManager::instance()->setImage(m_annotationDocument->renderToImage());
+        auto image = m_annotationDocument->renderToImage();
+        auto canvasPos = m_annotationDocument->canvasRect().topLeft();
+        ImageMetaData::setLogicalXY(image, canvasPos.x(), canvasPos.y());
+        ExportManager::instance()->setImage(image);
     }, Qt::QueuedConnection); // QueuedConnection to help prevent making the visible render lag.
 
     // set up shortcuts
@@ -1432,7 +1440,10 @@ void SpectacleCore::syncExportImage()
     if (!m_annotationSyncTimer->isActive()) {
         return;
     }
-    setExportImage(m_annotationDocument->renderToImage());
+    auto image = m_annotationDocument->renderToImage();
+    auto canvasPos = m_annotationDocument->canvasRect().topLeft();
+    ImageMetaData::setLogicalXY(image, canvasPos.x(), canvasPos.y());
+    setExportImage(image);
 }
 
 // A convenient way to stop the sync timer and set the export image.
